Package: BicARE
Version: 1.69.0
Date: 2008-06-05
Title: Biclustering Analysis and Results Exploration
Depends: R (>= 1.8.0), Biobase (>= 2.5.5), multtest, GSEABase, GO.db
Imports: methods
Suggests: hgu95av2
Author: Pierre Gestraud
Maintainer: Pierre Gestraud <pierre.gestraud@curie.fr>
Description: Biclustering Analysis and Results Exploration.
License: GPL-2
URL: http://bioinfo.curie.fr
biocViews: Microarray, Transcription, Clustering
git_url: https://git.bioconductor.org/packages/BicARE
git_branch: devel
git_last_commit: 8dec4bf
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.23
Date/Publication: 2025-10-31
NeedsCompilation: yes
Packaged: 2025-10-31 20:44:11 UTC; biocbuild
