useDynLib(BicARE)
export(FLOC, bicluster, testAnnot, testSet, residue, makeReport)
S3method(print, biclustering)
S3method(plot, bicluster)
importFrom("grDevices", "dev.off", "png")
importFrom("graphics", "axis", "matplot", "par")
importFrom("methods", "new")
importFrom("stats", "chisq.test", "phyper", "runif", "var")
importFrom("utils", "browseURL")
import("Biobase")
import("GSEABase")
import("multtest")
import("GO.db")